summaryrefslogtreecommitdiffstats
path: root/include/arpa
diff options
context:
space:
mode:
authorwollman <wollman@FreeBSD.org>1996-06-13 20:45:05 +0000
committerwollman <wollman@FreeBSD.org>1996-06-13 20:45:05 +0000
commitab56e8b192f1b86fc9601d31ae4f9a1f0ab4a9d8 (patch)
treea635ddac80f364e7231486e0658e824d279d1cfc /include/arpa
parentfffbd5d72119058c49e9a9072ce471d48c3cb30c (diff)
downloadFreeBSD-src-ab56e8b192f1b86fc9601d31ae4f9a1f0ab4a9d8.zip
FreeBSD-src-ab56e8b192f1b86fc9601d31ae4f9a1f0ab4a9d8.tar.gz
Add an independent implementation of addr2ascii(3) and ascii2addr(3)
following the API of the INRIA IPv6 implementation.
Diffstat (limited to 'include/arpa')
-rw-r--r--include/arpa/inet.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/include/arpa/inet.h b/include/arpa/inet.h
index 014277c..027f443 100644
--- a/include/arpa/inet.h
+++ b/include/arpa/inet.h
@@ -31,16 +31,21 @@
* SUCH DAMAGE.
*
* @(#)inet.h 8.1 (Berkeley) 6/2/93
+ * $Id$
*/
#ifndef _ARPA_INET_H_
#define _ARPA_INET_H_
/* External definitions for functions in inet(3) */
#include <sys/cdefs.h>
+struct in_addr;
+
__BEGIN_DECLS
+int ascii2addr __P((int, const char *, void *));
+char *addr2ascii __P((int, const void *, int, char *));
unsigned long inet_addr __P((const char *));
int inet_aton __P((const char *, struct in_addr *));
unsigned long inet_lnaof __P((struct in_addr));
@@ -31,16 +31,21 @@
#ifndef _ARPA_INET_H_
#define _ARPA_INET_H_
-/* External definitions for functions in inet(3) */
+/* External definitions for functions in inet(3), addr2ascii(3) */
#include <sys/cdefs.h>
OpenPOWER on IntegriCloud